==> adminer-3.1.0.zip: adminer-3.1.0/adminer/lang/pl.inc.php <==
<?php
$translations = array(
	// hidden because of poor quality according to author Helmut von Ślask cieszyński
	'Login' => 'Zalogować się',
	'Logout successful.' => 'Wylogowanie pomyślne.',
	'Invalid credentials.' => 'Nieprawidłowe dane.',
	'Server' => 'Serwer',
	'Username' => 'Użytkownik',
	'Password' => 'Hasło',
	'Select database' => 'Wybierz bazę danych',
	'Invalid database.' => 'Nie znaleziono bazę danych.',
	'Create new database' => 'Utwórz nową bazę danych',
	'Table has been dropped.' => 'Tabela została usunięta.',
	'Table has been altered.' => 'Tabela została zmieniona.',
	'Table has been created.' => 'Tabela została utworzona.',
	'Alter table' => 'Zmień tabelę',
	'Create table' => 'Utwórz nową tabelę',
	'Table name' => 'Nazwa tabeli',
	'engine' => 'składowanie',
	'collation' => 'porównywanie',
	'Column name' => 'Nazwa kolumny',
	'Type' => 'Typ',
	'Length' => 'Długość',
	'Auto Increment' => 'Auto Increment',
	'Options' => 'Operacje',
	'Save' => 'Zachowaj',
	'Drop' => 'Usuń',
	'Database has been dropped.' => 'Baza danych została usunięta.',
	'Database has been created.' => 'Baza danych została utworzona.',
	'Database has been renamed.' => 'Baza danych została przemianowana.',
	'Database has been altered.' => 'Baza danych została zmieniona.',
	'Alter database' => 'Zmień bazę danych',
	'Create database' => 'Utwórz bazę danych',
	'SQL command' => 'SQL zapytanie',
	'Dump' => 'Eksport',
	'Logout' => 'Wyjście',
	'database' => 'baza danych',
	'Use' => 'Vybrat',
	'No tables.' => 'Nie znaleziono tabeli.',
	'select' => 'pokaż',
	'Create new table' => 'Utwórz nową tabelę',
	'Item has been deleted.' => 'Rekord został usunięty.',
	'Item has been updated.' => 'Rekord został aktualizowany.',
	'Item%s has been inserted.' => 'Rekord%s został włożony.',
	'Edit' => 'Edytuj',
	'Insert' => 'Dodaj',
	'Save and insert next' => 'Wykonaj i dodaj następny',
	'Delete' => 'Usuń',
	'Database' => 'Baza danych',
	'Routines' => 'Procedury i funkcje',
	'Indexes have been altered.' => 'Indeksy uległy zmianie.',
	'Indexes' => 'Indeksy',
	'Alter indexes' => 'Edytuj indeksy',
	'Add next' => 'Dodaj następny',
	'Language' => 'Język',
	'Select' => 'Przeglądaj',
	'New item' => 'Nowy rekord',
	'Search' => 'Szukaj',
	'Sort' => 'Sortuj',
	'descending' => 'malejąco',
	'Limit' => 'Limit',
	'No rows.' => 'Pusty wynik.',
	'Action' => 'Czynność',
	'edit' => 'zmień',
	'Page' => 'Strona',
	'Query executed OK, %d row(s) affected.' => array('Wykonanie pomyślne, zmieniono %d rekord.',
	 'Wykonanie pomyślne, zmieniono %d rekordy.',
	 'Wykonanie pomyślne, zmieniono %d rekordów.'),
	'Error in query' => 'Bląd w zapytaniu',
	'Execute' => 'Wykonaj',
	'Table' => 'Tabela',
	'Foreign keys' => 'Klucze obce',
	'Triggers' => 'Wyzwalacze',
	'View' => 'Perspektywa',
	'Unable to select the table' => 'Nie mozna było przeglądać tabel',
	'Invalid CSRF token. Send the form again.' => 'Niepoprawny CSRF token. Odeślij ponownie.',
	'Comment' => 'Komentarz',
	'Default values' => 'Wartości domyślne',
	'%d byte(s)' => array('%d bajt', '%d bajty', '%d bajtów'),
	'No commands to execute.' => 'Nic do wykonania.',
	'Unable to upload a file.' => 'Nie było możliwe nagrać plik.',
	'File upload' => 'Nagranie pliku',
	'File uploads are disabled.' => 'Nagranie pliku nie jest dozwolone.',
	'Routine has been called, %d row(s) affected.' => array('Procedura była uruchomiona, został zmieniony %d rekord.', 
	 'Procedura była uruchomiona, zostały zmienione %d rekordy.', 
	 'Procedura była uruchomiona, %d rekordów zostało zmienionych.'),
	'Call' => 'Uruchomić',
	'No extension' => 'Bez rozszerzenia',
	'None of the supported PHP extensions (%s) are available.' => 'Nie jest dostępne żadne z PHP rozszerzeń (%s).',
	'Session support must be enabled.' => 'Session zmienne muszą być dozwolone.',
	'Session expired, please login again.' => 'Minął czas session, zaloguj się ponownie.',
	'Text length' => 'Długość tekstu',
	'Foreign key has been dropped.' => 'Klucz obcy został usunięty.',
	'Foreign key has been altered.' => 'Klucz obcy został zmieniony.',
	'Foreign key has been created.' => 'Klucz obcy został utworzony.',
	'Foreign key' => 'Obcy klucz',
	'Target table' => 'Tabela celowa',
	'Change' => 'Zmienić',
	'Source' => 'Źródło',
	'Target' => 'Cel',
	'Add column' => 'Dodaj kolumnę',
	'Alter' => 'Zmień',
	'Add foreign key' => 'Dodaj klucz obcy',
	'ON DELETE' => 'W przypadku usunięcia',
	'ON UPDATE' => 'W przypadku zmiany',
	'Index Type' => 'Typ indeksu',
	'Column (length)' => 'Kolumna (długość)',
	'View has been dropped.' => 'Perspektywa została usunięta.',
	'View has been altered.' => 'Perspektywa została zmieniona.',
	'View has been created.' => 'Perspektywa została utworzona.',
	'Alter view' => 'Zmień perspektywę',
	'Create view' => 'Utwórz perspektywę',
	'Name' => 'Nazwa',
	'Process list' => 'Lista procesów',
	'%d process(es) have been killed.' => array('Wątek %d został unicestwiony.', 
		'Unicestwiono %d wątki.', 
		'Unicestwiono %d wątków.'),
	'Kill' => 'Unicestwij',
	'Parameter name' => 'Nazwa parametru',
	'Database schema' => 'Schemat bazy danych',
	'Create procedure' => 'Utwórz procedurę',
	'Create function' => 'Utwórz funkcję',
	'Routine has been dropped.' => 'Procedura została usunięta.',
	'Routine has been altered.' => 'Procedura została zmieniona.',
	'Routine has been created.' => 'Procedura została utworzona.',
	'Alter function' => 'Zmień funkcję',
	'Alter procedure' => 'Zmień procedurę',
	'Return type' => 'Typ zwracania',
	'Add trigger' => 'Dodaj wyzwalacz',
	'Trigger has been dropped.' => 'Wyzwalacz został usunięty.',
	'Trigger has been altered.' => 'Wyzwalacz został zmieniony.',
	'Trigger has been created.' => 'Wyzwalacz został utworzony.',
	'Alter trigger' => 'Zmień wyzwalacz',
	'Create trigger' => 'Utwórz wyzwalacz',
	'Time' => 'Czas',
	'Event' => 'Wydarzenie',
	'%s version: %s through PHP extension %s' => 'Wersja %s: %s przez PHP rozszerzenie %s',
	'%d row(s)' => array('%d linia', '%d linie ', '%d linii'),
	'Remove' => 'Usunąć',
	'Are you sure?' => 'Naprawdę?',
	'Privileges' => 'Uprawnienia użytkowników',
	'Create user' => 'Utwórz użytkownika',
	'User has been dropped.' => 'Użytkownik został usunięty.',
	'User has been altered.' => 'Użytkownik został zmieniony.',
	'User has been created.' => 'Użytkownik został utworzony.',
	'Hashed' => 'Hashed',
	'Column' => 'Kolumna',
	'Routine' => 'Procedura',
	'Grant' => 'Udzielić',
	'Revoke' => 'Odwołać',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 
		'Zbyt duże POST data. Zmiejszyj data albo podwyższ wartość w konfiguracji %s.',
	'Logged as: %s' => 'Zalogowany jako: %s',
	'Move up' => 'Przesuń w górę',
	'Move down' => 'Przesuń w dół',
	'Functions' => 'Funkcje',
	'Aggregation' => 'Agregacje',
	'Export' => 'Eksport',
	'Output' => 'Wyjście',
	'open' => 'otworzyć',
	'save' => 'uchować',
	'Format' => 'Format',
	'Tables' => 'Tabele',
	'Data' => 'Data',
	'Event has been dropped.' => 'Wydarzenie zostało usunięte.',
	'Event has been altered.' => 'Wydarzenie zostało zmienione.',
	'Event has been created.' => 'Wydarzenie zostało utworzone.',
	'Alter event' => 'Zmień wydarzenie',
	'Create event' => 'Utwórz wydarzenie',
	'At given time' => 'O danym czasie',
	'Every' => 'Każdych',
	'Events' => 'Wydarzenie',
	'Schedule' => 'Harmonogram',
	'Start' => 'Początek',
	'End' => 'Koniec',
	'Status' => 'Status',
	'On completion preserve' => 'Po zakończeniu zachować',
	'Tables and views' => 'Tabele a perspektywy',
	'Data Length' => 'Długość danych',
	'Index Length' => 'Długość indeksów',
	'Data Free' => 'Wolne miejsce',
	'Collation' => 'Porównywanie',
	'Analyze' => 'Analizuj',
	'Optimize' => 'Optymalizacja',
	'Check' => 'Sprawdź',
	'Repair' => 'Napraw',
	'Truncate' => 'Wypróźnij',
	'Tables have been truncated.' => 'Tabele zostały wypróźnione.',
	'Rows' => 'Linie',
	',' => ' ',
	'Tables have been moved.' => 'Tabele zostały przesunięte',
	'Move to other database' => 'Przesunąć do innej bazy danych',
	'Move' => 'Przesunąć',
	'Engine' => 'Engine',
	'Save and continue edit' => 'Zapisz i kontynuuj edycję',
	'original' => 'oryginalny',
	'%d item(s) have been affected.' => array('Został dotknięty %d rekord.', 
	 'Zostały dotknięte %d rekordy.',
	 'Zostało dotkniętych %d rekordów.'),
	'whole result' => 'cały wynik',
	'Tables have been dropped.' => 'Tabele zostały usunięte.',
	'Clone' => 'Klonować',
	'Partition by' => 'Rozdzielić przez',
	'Partitions' => 'Rozdziały',
	'Partition name' => 'Nazwa rozdziału',
	'Values' => 'Wartości',
	'%d row(s) have been imported.' => array('%d rekord został importowany.', 
	 '%d rekordy zostały importowane.', 
	 'Zostało importowanych %d rekordów.'),
	'CSV Import' => 'Import CSV',
	'Import' => 'Import',
	'Show structure' => 'Pokaż całą strukturę',
	'Select data' => 'Pokaż dane',
	'Stop on error' => 'Stop w przypadku błędu',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 
	  'Przekroczono maksymalną liczbę pól. Zwiększ %s i %s.',
	'anywhere' => 'kdziekolwiek',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$6.$4.$1',
	'[yyyy]-mm-dd' => 'd.m.[rrrr]',
	'History' => 'Historia',
	'Variables' => 'Zmienne',
	'Source and target columns must have the same data type, there must be an index on the target
	 columns and referenced data must exist.' => 
	 'Zdrojové a cílové sloupce musí mít stejný datový typ, nad cílovými sloupci 
	 musí být definován index a odkazovaná data musí existovat.',
	'E-mail' => 'E-mail',
	'From' => 'Nadawca',
	'Subject' => 'Temat',
	'Send' => 'Wyślij',
	'%d e-mail(s) have been sent.' => array('Został wysłany %d e-mail.', 
	'Zostały wysłane %d e-maile.', 'Zostało wysłanych %d e-mailów.'),
	'Run file' => 'Uruchomić plik',
	'Numbers' => 'Numery',
	'Date and time' => 'Datum i czas',
	'Strings' => 'Typu string',
	'Binary' => 'Binarny',
	'Lists' => 'Listy',
	'Relations' => 'Relacje',
	'Maximum allowed file size is %sB.' => 'Maksymalna wielkość pliku to %sB.',
	'Clear' => 'Wyczyścić',
	'Editor' => 'Edytor',
	'Webserver file %s' => 'Plik %s na serweru',
	'File does not exist.' => 'Plik nieistnieje.',
	'Permanent login' => 'Logowanie stałe',
	'%d in total' => '%d w sumie',
	'Attachments' => 'Załączniki',
	'System' => 'System',
	'last' => 'ostatni',
	'Network' => 'Sieć',
	'Geometry' => 'Geometria',
	'Databases have been dropped.' => 'Baze danych zostały usunięte.',
	'File exists.' => 'Plik istnieje.',
	'Double click on a value to modify it.' => 'Kliknij podwójnie by zmienić wartość.',
	'Increase text length to modify this value.' => 'Aby zmienić wartość to potrzeba powiększyć długość tekstu.',
	'Use edit link to modify this value.' => 'Użyj linku zmienić by poprawić wartość.',
	'Alter schema' => 'Zmienić schemat',
	'Create schema' => 'Utwórz schemat',
	'Schema has been dropped.' => 'Schemat został usunięty.',
	'Schema has been created.' => 'Schemat został utworzony.',
	'Schema has been altered.' => 'Schemat został zmieniony.',
	'schema' => 'schemat',
	'Schema' => 'Schemat',
	'Sequences' => 'Sekwencje',
	'Create sequence' => 'Utwórz sekwencję',
	'Sequence has been dropped.' => 'Sekwencja została usunięta.',
	'Sequence has been created.' => 'Sekwencja została utworzona.',
	'Sequence has been altered.' => 'Sekwencja została zmieniona.',
	'Alter sequence' => 'Zmień sekwencję',
	'User types' => 'Typy definiowane użytkownikiem',
	'Create type' => 'Utwórz definiowany typ',
	'Type has been dropped.' => 'Typ został usunięty.',
	'Type has been created.' => 'Typ został utworzony.',
	'Alter type' => 'Zmień typ',
	'Search data in tables' => 'Wyszukaj data w tabelach',
	'From server' => 'Ze serweru',
	'empty' => 'puste',
	'now' => 'teraz',
);

==> adminer-3.2.0.zip: adminer-3.2.0/adminer/lang/pl.inc.php <==
<?php
$translations = array(
	'Login' => 'Zalogować się',
	'Logout successful.' => 'Wylogowanie pomyślne.',
	'Invalid credentials.' => 'Nieprawidłowe dane.',
	'Server' => 'Serwer',
	'Username' => 'Użytkownik',
	'Password' => 'Hasło',
	'Select database' => 'Wybierz bazę danych',
	'Invalid database.' => 'Nie znaleziono bazę danych.',
	'Create new database' => 'Utwórz nową bazę danych',
	'Table has been dropped.' => 'Tabela została usunięta.',
	'Table has been altered.' => 'Tabela została zmieniona.',
	'Table has been created.' => 'Tabela została utworzona.',
	'Alter table' => 'Zmień tabelę',
	'Create table' => 'Utwórz nową tabelę',
	'Table name' => 'Nazwa tabeli',
	'engine' => 'składowanie',
	'collation' => 'porównywanie',
	'Column name' => 'Nazwa kolumny',
	'Type' => 'Typ',
	'Length' => 'Długość',
	'Auto Increment' => 'Auto Increment',
	'Options' => 'Operacje',
	'Save' => 'Zachowaj',
	'Drop' => 'Usuń',
	'Database has been dropped.' => 'Baza danych została usunięta.',
	'Database has been created.' => 'Baza danych została utworzona.',
	'Database has been renamed.' => 'Baza danych została przemianowana.',
	'Database has been altered.' => 'Baza danych została zmieniona.',
	'Alter database' => 'Zmień bazę danych',
	'Create database' => 'Utwórz bazę danych',
	'SQL command' => 'SQL zapytanie',
	'Dump' => 'Eksport',
	'Logout' => 'Wyjście',
	'database' => 'baza danych',
	'Use' => 'Vybrat',
	'No tables.' => 'Nie znaleziono tabeli.',
	'select' => 'pokaż',
	'Create new table' => 'Utwórz nową tabelę',
	'Item has been deleted.' => 'Rekord został usunięty.',
	'Item has been updated.' => 'Rekord został aktualizowany.',
	'Item%s has been inserted.' => 'Rekord%s został włożony.',
	'Edit' => 'Edytuj',
	'Insert' => 'Dodaj',
	'Save and insert next' => 'Wykonaj i dodaj następny',
	'Delete' => 'Usuń',
	'Database' => 'Baza danych',
	'Routines' => 'Procedury i funkcje',
	'Indexes have been altered.' => 'Indeksy uległy zmianie.',
	'Indexes' => 'Indeksy',
	'Alter indexes' => 'Edytuj indeksy',
	'Add next' => 'Dodaj następny',
	'Language' => 'Język',
	'Select' => 'Przeglądaj',
	'New item' => 'Nowy rekord',
	'Search' => 'Szukaj',
	'Sort' => 'Sortuj',
	'descending' => 'malejąco',
	'Limit' => 'Limit',
	'No rows.' => 'Pusty wynik.',
	'Action' => 'Czynność',
	'edit' => 'zmień',
	'Page' => 'Strona',
	'Query executed OK, %d row(s) affected.' => array('Wykonanie pomyślne, zmieniono %d rekord.', 'Wykonanie pomyślne, zmieniono %d rekordy.', 'Wykonanie pomyślne, zmieniono %d rekordów.'),
	'Error in query' => 'Bląd w zapytaniu',
	'Execute' => 'Wykonaj',
	'Table' => 'Tabela',
	'Foreign keys' => 'Klucze obce',
	'Triggers' => 'Wyzwalacze',
	'View' => 'Perspektywa',
	'Unable to select the table' => 'Nie mozna było przeglądać tabel',
	'Invalid CSRF token. Send the form again.' => 'Niepoprawny CSRF token. Odeślij ponownie.',
	'Comment' => 'Komentarz',
	'Default values' => 'Wartości domyślne',
	'%d byte(s)' => array('%d bajt', '%d bajty', '%d bajtów'),
	'No commands to execute.' => 'Nic do wykonania.',
	'Unable to upload a file.' => 'Nie było możliwe nagrać plik.',
	'File upload' => 'Nagranie pliku',
	'File uploads are disabled.' => 'Nagranie pliku nie jest dozwolone.',
	'Routine has been called, %d row(s) affected.' => array('Procedura była uruchomiona, został zmieniony %d rekord.', 'Procedura była uruchomiona, zostały zmienione %d rekordy.', 'Procedura była uruchomiona, %d rekordów zostało zmienionych.'),
	'Call' => 'Uruchomić',
	'No extension' => 'Bez rozszerzenia',
	'None of the supported PHP extensions (%s) are available.' => 'Nie jest dostępne żadne z PHP rozszerzeń (%s).',
	'Session support must be enabled.' => 'Session zmienne muszą być dozwolone.',
	'Session expired, please login again.' => 'Minął czas session, zaloguj się ponownie.',
	'Text length' => 'Długość tekstu',
	'Foreign key has been dropped.' => 'Klucz obcy został usunięty.',
	'Foreign key has been altered.' => 'Klucz obcy został zmieniony.',
	'Foreign key has been created.' => 'Klucz obcy został utworzony.',
	'Foreign key' => 'Obcy klucz',
	'Target table' => 'Tabela celowa',
	'Change' => 'Zmienić',
	'Source' => 'Źródło',
	'Target' => 'Cel',
	'Add column' => 'Dodaj kolumnę',
	'Alter' => 'Zmień',
	'Add foreign key' => 'Dodaj klucz obcy',
	'ON DELETE' => 'W przypadku usunięcia',
	'ON UPDATE' => 'W przypadku zmiany',
	'Index Type' => 'Typ indeksu',
	'Column (length)' => 'Kolumna (długość)',
	'View has been dropped.' => 'Perspektywa została usunięta.',
	'View has been altered.' => 'Perspektywa została zmieniona.',
	'View has been created.' => 'Perspektywa została utworzona.',
	'Alter view' => 'Zmień perspektywę',
	'Create view' => 'Utwórz perspektywę',
	'Name' => 'Nazwa',
	'Process list' => 'Lista procesów',
	'%d process(es) have been killed.' => array('Wątek %d został unicestwiony.', 'Unicestwiono %d wątki.', 'Unicestwiono %d wątków.'),
	'Kill' => 'Unicestwij',
	'Parameter name' => 'Nazwa parametru',
	'Database schema' => 'Schemat bazy danych',
	'Create procedure' => 'Utwórz procedurę',
	'Create function' => 'Utwórz funkcję',
	'Routine has been dropped.' => 'Procedura została usunięta.',
	'Routine has been altered.' => 'Procedura została zmieniona.',
	'Routine has been created.' => 'Procedura została utworzona.',
	'Alter function' => 'Zmień funkcję',
	'Alter procedure' => 'Zmień procedurę',
	'Return type' => 'Typ zwracania',
	'Add trigger' => 'Dodaj wyzwalacz',
	'Trigger has been dropped.' => 'Wyzwalacz został usunięty.',
	'Trigger has been altered.' => 'Wyzwalacz został zmieniony.',
	'Trigger has been created.' => 'Wyzwalacz został utworzony.',
	'Alter trigger' => 'Zmień wyzwalacz',
	'Create trigger' => 'Utwórz wyzwalacz',
	'Time' => 'Czas',
	'Event' => 'Wydarzenie',
	'%s version: %s through PHP extension %s' => 'Wersja %s: %s przez PHP rozszerzenie %s',
	'%d row(s)' => array('%d linia', '%d linie ', '%d linii'),
	'Remove' => 'Usunąć',
	'Are you sure?' => 'Naprawdę?',
	'Privileges' => 'Uprawnienia użytkowników',
	'Create user' => 'Utwórz użytkownika',
	'User has been dropped.' => 'Użytkownik został usunięty.',
	'User has been altered.' => 'Użytkownik został zmieniony.',
	'User has been created.' => 'Użytkownik został utworzony.',
	'Hashed' => 'Hashed',
	'Column' => 'Kolumna',
	'Routine' => 'Procedura',
	'Grant' => 'Udzielić',
	'Revoke' => 'Odwołać',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Zbyt duże POST data. Zmiejszyj data albo podwyższ wartość w konfiguracji %s.',
	'Logged as: %s' => 'Zalogowany jako: %s',
	'Move up' => 'Przesuń w górę',
	'Move down' => 'Przesuń w dół',
	'Functions' => 'Funkcje',
	'Aggregation' => 'Agregacje',
	'Export' => 'Eksport',
	'Output' => 'Wyjście',
	'open' => 'otworzyć',
	'save' => 'uchować',
	'Format' => 'Format',
	'Tables' => 'Tabele',
	'Data' => 'Data',
	'Event has been dropped.' => 'Wydarzenie zostało usunięte.',
	'Event has been altered.' => 'Wydarzenie zostało zmienione.',
	'Event has been created.' => 'Wydarzenie zostało utworzone.',
	'Alter event' => 'Zmień wydarzenie',
	'Create event' => 'Utwórz wydarzenie',
	'At given time' => 'O danym czasie',
	'Every' => 'Każdych',
	'Events' => 'Wydarzenie',
	'Schedule' => 'Harmonogram',
	'Start' => 'Początek',
	'End' => 'Koniec',
	'Status' => 'Status',
	'On completion preserve' => 'Po zakończeniu zachować',
	'Tables and views' => 'Tabele a perspektywy',
	'Data Length' => 'Długość danych',
	'Index Length' => 'Długość indeksów',
	'Data Free' => 'Wolne miejsce',
	'Collation' => 'Porównywanie',
	'Analyze' => 'Analizuj',
	'Optimize' => 'Optymalizacja',
	'Check' => 'Sprawdź',
	'Repair' => 'Napraw',
	'Truncate' => 'Wypróźnij',
	'Tables have been truncated.' => 'Tabele zostały wypróźnione.',
	'Rows' => 'Linie',
	',' => ' ',
	'Tables have been moved.' => 'Tabele zostały przesunięte',
	'Move to other database' => 'Przesunąć do innej bazy danych',
	'Move' => 'Przesunąć',
	'Engine' => 'Engine',
	'Save and continue edit' => 'Zapisz i kontynuuj edycję',
	'original' => 'oryginalny',
	'%d item(s) have been affected.' => array('Został dotknięty %d rekord.', 'Zostały dotknięte %d rekordy.', 'Zostało dotkniętych %d rekordów.'),
	'whole result' => 'cały wynik',
	'Tables have been dropped.' => 'Tabele zostały usunięte.',
	'Clone' => 'Klonować',
	'Partition by' => 'Rozdzielić przez',
	'Partitions' => 'Rozdziały',
	'Partition name' => 'Nazwa rozdziału',
	'Values' => 'Wartości',
	'%d row(s) have been imported.' => array('%d rekord został importowany.', '%d rekordy zostały importowane.', 'Zostało importowanych %d rekordów.'),
	'Import' => 'Import',
	'Show structure' => 'Pokaż całą strukturę',
	'Select data' => 'Pokaż dane',
	'Stop on error' => 'Stop w przypadku błędu',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'Przekroczono maksymalną liczbę pól. Zwiększ %s i %s.',
	'anywhere' => 'kdziekolwiek',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$6.$4.$1',
	'[yyyy]-mm-dd' => 'd.m.[rrrr]',
	'History' => 'Historia',
	'Variables' => 'Zmienne',
	'E-mail' => 'E-mail',
	'From' => 'Nadawca',
	'Subject' => 'Temat',
	'Send' => 'Wyślij',
	'%d e-mail(s) have been sent.' => array('Został wysłany %d e-mail.', 'Zostały wysłane %d e-maile.', 'Zostało wysłanych %d e-mailów.'),
	'Run file' => 'Uruchomić plik',
	'Numbers' => 'Numery',
	'Date and time' => 'Datum i czas',
	'Strings' => 'Typu string',
	'Binary' => 'Binarny',
	'Lists' => 'Listy',
	'Relations' => 'Relacje',
	'Maximum allowed file size is %sB.' => 'Maksymalna wielkość pliku to %sB.',
	'Clear' => 'Wyczyścić',
	'Editor' => 'Edytor',
	'Webserver file %s' => 'Plik %s na serweru',
	'File does not exist.' => 'Plik nieistnieje.',
	'Permanent login' => 'Logowanie stałe',
	'%d in total' => '%d w sumie',
	'Attachments' => 'Załączniki',
	'System' => 'System',
	'last' => 'ostatni',
	'Network' => 'Sieć',
	'Geometry' => 'Geometria',
	'Databases have been dropped.' => 'Baze danych zostały usunięte.',
	'File exists.' => 'Plik istnieje.',
	'Double click on a value to modify it.' => 'Kliknij podwójnie by zmienić wartość.',
	'Increase text length to modify this value.' => 'Aby zmienić wartość to potrzeba powiększyć długość tekstu.',
	'Use edit link to modify this value.' => 'Użyj linku zmienić by poprawić wartość.',
	'Alter schema' => 'Zmienić schemat',
	'Create schema' => 'Utwórz schemat',
	'Schema has been dropped.' => 'Schemat został usunięty.',
	'Schema has been created.' => 'Schemat został utworzony.',
	'Schema has been altered.' => 'Schemat został zmieniony.',
	'schema' => 'schemat',
	'Schema' => 'Schemat',
	'Sequences' => 'Sekwencje',
	'Create sequence' => 'Utwórz sekwencję',
	'Sequence has been dropped.' => 'Sekwencja została usunięta.',
	'Sequence has been created.' => 'Sekwencja została utworzona.',
	'Sequence has been altered.' => 'Sekwencja została zmieniona.',
	'Alter sequence' => 'Zmień sekwencję',
	'User types' => 'Typy definiowane użytkownikiem',
	'Create type' => 'Utwórz definiowany typ',
	'Type has been dropped.' => 'Typ został usunięty.',
	'Type has been created.' => 'Typ został utworzony.',
	'Alter type' => 'Zmień typ',
	'Search data in tables' => 'Wyszukaj data w tabelach',
	'From server' => 'Ze serweru',
	'empty' => 'puste',
	'now' => 'teraz',
);
